diff OrthancServer/FromDcmtkBridge.cpp @ 62:a70bb32802ae orthanc-renaming

renaming Server
author Sebastien Jodogne <s.jodogne@gmail.com>
date Sun, 16 Sep 2012 09:33:19 +0200
parents 4bc019d2f969
children aa65ced5f0f0
line wrap: on
line diff
--- a/OrthancServer/FromDcmtkBridge.cpp	Sun Sep 16 09:30:31 2012 +0200
+++ b/OrthancServer/FromDcmtkBridge.cpp	Sun Sep 16 09:33:19 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -22,7 +22,7 @@
 
 #include "ToDcmtkBridge.h"
 #include "DicomIntegerPixelAccessor.h"
-#include "../Core/PalanthirException.h"
+#include "../Core/OrthancException.h"
 #include "../Core/PngWriter.h"
 #include "../Core/DicomFormat/DicomString.h"
 #include "../Core/DicomFormat/DicomNullValue.h"
@@ -45,7 +45,7 @@
 
 #include <boost/math/special_functions/round.hpp>
 
-namespace Palanthir
+namespace Orthanc
 {
   void FromDcmtkBridge::Convert(DicomMap& target, DcmDataset& dataset)
   {
@@ -73,7 +73,7 @@
   {
     if (!element.isLeaf())
     {
-      throw PalanthirException("Only applicable to leaf elements");
+      throw OrthancException("Only applicable to leaf elements");
     }
 
     if (element.isaString())
@@ -370,7 +370,7 @@
     DcmFileFormat dicom;
     if (!dicom.loadFile(path.c_str()).good())
     {
-      throw PalanthirException(ErrorCode_BadFileFormat);
+      throw OrthancException(ErrorCode_BadFileFormat);
     }
     else
     {
@@ -473,7 +473,7 @@
       break;
 
     default:
-      throw PalanthirException(ErrorCode_NotImplemented);
+      throw OrthancException(ErrorCode_NotImplemented);
     }
 
     if (accessor.get() == NULL ||
@@ -500,7 +500,7 @@
         break;
 
       default:
-        throw PalanthirException(ErrorCode_NotImplemented);
+        throw OrthancException(ErrorCode_NotImplemented);
       }
     }
   }
@@ -525,7 +525,7 @@
     }
     else
     {
-      throw PalanthirException(ErrorCode_BadFileFormat);
+      throw OrthancException(ErrorCode_BadFileFormat);
     }
   }
 
@@ -556,7 +556,7 @@
     if (entry == NULL)
     {
       dcmDataDict.unlock();
-      throw PalanthirException("Unknown DICOM tag");
+      throw OrthancException("Unknown DICOM tag");
     }
     else
     {
@@ -585,7 +585,7 @@
   {
     if (result.type() != Json::objectValue)
     {
-      throw PalanthirException(ErrorCode_BadParameterType);
+      throw OrthancException(ErrorCode_BadParameterType);
     }
 
     result.clear();
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium